==> Pyrogram-0.17.0-py3-none-any.whl: pyrogram/api/types/help/__init__.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .config_simple import ConfigSimple
from .app_update import AppUpdate
from .no_app_update import NoAppUpdate
from .invite_text import InviteText
from .support import Support
from .terms_of_service import TermsOfService
from .recent_me_urls import RecentMeUrls
from .proxy_data_empty import ProxyDataEmpty
from .proxy_data_promo import ProxyDataPromo
from .terms_of_service_update_empty import TermsOfServiceUpdateEmpty
from .terms_of_service_update import TermsOfServiceUpdate
from .deep_link_info_empty import DeepLinkInfoEmpty
from .deep_link_info import DeepLinkInfo
from .passport_config_not_modified import PassportConfigNotModified
from .passport_config import PassportConfig
from .support_name import SupportName
from .user_info_empty import UserInfoEmpty
from .user_info import UserInfo

==> Pyrogram-0.18.0-py3-none-any.whl: pyrogram/api/types/help/__init__.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .config_simple import ConfigSimple
from .app_update import AppUpdate
from .no_app_update import NoAppUpdate
from .invite_text import InviteText
from .support import Support
from .terms_of_service import TermsOfService
from .recent_me_urls import RecentMeUrls
from .terms_of_service_update_empty import TermsOfServiceUpdateEmpty
from .terms_of_service_update import TermsOfServiceUpdate
from .deep_link_info_empty import DeepLinkInfoEmpty
from .deep_link_info import DeepLinkInfo
from .passport_config_not_modified import PassportConfigNotModified
from .passport_config import PassportConfig
from .support_name import SupportName
from .user_info_empty import UserInfoEmpty
from .user_info import UserInfo
from .promo_data_empty import PromoDataEmpty
from .promo_data import PromoData
